{% load i18n %}
<div id="eventModal" class="modal fade" role="dialog">
  <div class="modal-dialog">

    <!-- Modal content-->
    <div class="modal-content">
      <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal">&times;</button>
        <h4 class="modal-title"><span id="EditorDelete"></span> {% trans "Event" %}</h4>
      </div>
      <div class="modal-body">
       <p>{% blocktrans %}Would you like to <span id="editordelete"></span> all occurrences in this event or just this occurrence?{% endblocktrans %}</p>
      </div>
      <div class="modal-footer">
        <a href='#' id='allevent'>
         <button type="button" class="btn btn-default">{% trans "All" %}</button>
        </a>

        <a href='#' id='thisevent'>
         <button type="button" class="btn btn-default">{% trans "This" %}</button>
        </a>

        <button type="button" class="btn btn-default" data-dismiss="modal">{% trans "Close" %}</button>
      </div>
    </div>

  </div>
</div>
