{% extends "base.html" %}
{% load i18n %}
{% block head_title %}{% trans "Available Calendars" %}{% endblock %}
{% block body %}
<h2>{% trans "Available Calendars" %}</h2>
<ul>
{% for cal in object_list %}
<li><b>{{ cal }}</b> :
  <a href="{% url "compact_calendar" cal.slug %}">{% trans "Small Month" %}</a> --
  <a href="{% url "month_calendar" cal.slug %}">{% trans "1 Month" %}</a> --
  <a href="{% url "tri_month_calendar" cal.slug %}">{% trans "3 Months" %}</a> --
  <a href="{% url "year_calendar" cal.slug %}">{% trans "This Year" %}</a> --
  <a href="{% url "week_calendar" cal.slug %}">{% trans "Weekly" %}</a> --
  <a href="{% url "day_calendar" cal.slug %}">{% trans "Daily" %}</a> --
  <a href="{% url "upcoming_events_feed" cal.id %}">{% trans "Feed" %}</a></li><br>
{% endfor %}
</ul>
{% endblock %}
