# Generated by Django 2.2.6 on 2019-10-25 18:52

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("schedule", "0011_event_calendar_not_null")]

    operations = [
        migrations.AlterField(
            model_name="event",
            name="creator",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="creator",
                to=settings.AUTH_USER_MODEL,
                verbose_name="creator",
            ),
        ),
        migrations.AlterField(
            model_name="event",
            name="rule",
            field=models.ForeignKey(
                blank=True,
                help_text="Select '----' for a one time only event.",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="schedule.Rule",
                verbose_name="rule",
            ),
        ),
    ]
